@@ -8,7 +8,7 @@ class DiagnosticSessionControl(BaseService):
     _sid = 0x10
 
     supported_negative_response = [	Response.Code.SubFunctionNotSupported, 
-                                                                    Response.Code.IncorrectMessageLegthOrInvalidFormat,
+                                                                    Response.Code.IncorrectMessageLengthOrInvalidFormat,
                                                                     Response.Code.ConditionsNotCorrect
                                                                     ]
     class Session(BaseSubfunction):
