@@ -6,7 +6,7 @@ class DynamicallyDefineDataIdentifier(BaseService):
     _sid = 0x2C
 
     supported_negative_response = [	 Response.Code.SubFunctionNotSupported,
-                                                    Response.Code.IncorrectMessageLegthOrInvalidFormat,
+                                                    Response.Code.IncorrectMessageLengthOrInvalidFormat,
                                                     Response.Code.ConditionsNotCorrect,
                                                     Response.Code.RequestOutOfRange,
                                                     Response.Code.SecurityAccessDenied
